@@ -71,6 +71,7 @@ class DataStore:
             "msas",
             "ncdb",
             "states",
+            "show_data_dir"
             "tracts_1990",
             "tracts_2000",
             "tracts_2010",
@@ -78,6 +79,18 @@ class DataStore:
 
         return atts
 
+    def show_data_dir(self):
+        """Print the location of the local geosnap data storage directory.
+
+        Returns
+        -------
+        string
+            location of local storage directory.
+        """
+        print(data_dir)
+        return data_dir
+
+
     def acs(self, year=2018, level="tract", states=None):
         """American Community Survey Data.
 
@@ -104,7 +117,7 @@ class DataStore:
                 "streaming remote data. Use `geosnap.io.store_acs() to store the data locally for better performance"
             )
             t = gpd.read_parquet(
-                f"s3://spatial-ucr/census/acs/acs_{year}_{level}.parquet"
+                f"s3://spatial-ucr/census/acs/acs_{year}_{level}.parquet",storage_options={"anon": True}
             )
         t = t.reset_index().rename(columns={"GEOID": "geoid"})
 
@@ -144,7 +157,7 @@ class DataStore:
                     "with the io.store_blocks_2010 function for better performance"
                 )
                 blks[state] = gpd.read_parquet(
-                    f"s3://spatial-ucr/census/blocks_2000/{state}.parquet"
+                    f"s3://spatial-ucr/census/blocks_2000/{state}.parquet",storage_options={"anon": True}
                 )
 
             if fips:
@@ -187,7 +200,7 @@ class DataStore:
                     "with the io.store_blocks_2010 function for better performance"
                 )
                 blks[state] = gpd.read_parquet(
-                    f"s3://spatial-ucr/census/blocks_2010/{state}.parquet"
+                    f"s3://spatial-ucr/census/blocks_2010/{state}.parquet",storage_options={"anon": True}
                 )
 
             if fips:
@@ -221,7 +234,7 @@ class DataStore:
                 "streaming remote data. Use `geosnap.io.store_census() to store the data locally for better performance"
             )
             t = gpd.read_parquet(
-                "s3://spatial-ucr/census/tracts_cartographic/tracts_1990_500k.parquet"
+                "s3://spatial-ucr/census/tracts_cartographic/tracts_1990_500k.parquet",storage_options={"anon": True}
             )
 
         if states:
@@ -252,7 +265,7 @@ class DataStore:
                 "streaming remote data. Use `geosnap.io.store_census() to store the data locally for better performance"
             )
             t = gpd.read_parquet(
-                "s3://spatial-ucr/census/tracts_cartographic/tracts_2000_500k.parquet"
+                "s3://spatial-ucr/census/tracts_cartographic/tracts_2000_500k.parquet",storage_options={"anon": True}
             )
         if states:
             t = t[t.geoid.str[:2].isin(states)]
@@ -284,7 +297,7 @@ class DataStore:
                 "streaming remote data. Use `geosnap.io.store_census() to store the data locally for better performance"
             )
             t = gpd.read_parquet(
-                "s3://spatial-ucr/census/tracts_cartographic/tracts_2010_500k.parquet"
+                "s3://spatial-ucr/census/tracts_cartographic/tracts_2010_500k.parquet",storage_options={"anon": True}
             )
 
         if states:
@@ -312,7 +325,7 @@ class DataStore:
             )
         except Exception:
             return gpd.read_parquet(
-                "s3://spatial-ucr/census/administrative/msas.parquet"
+                "s3://spatial-ucr/census/administrative/msas.parquet",storage_options={"anon": True}
             ).sort_values(by="name")
 
     def states(self):
@@ -329,7 +342,7 @@ class DataStore:
             return gpd.read_parquet(pathlib.Path(data_dir, "states.parquet"))
         except Exception:
             return gpd.read_parquet(
-                "s3://spatial-ucr/census/administrative/states.parquet"
+                "s3://spatial-ucr/census/administrative/states.parquet",storage_options={"anon": True}
             )
 
     def counties(self):
@@ -351,7 +364,7 @@ class DataStore:
             return gpd.read_parquet(pathlib.Path(data_dir, "counties.parquet"))
         except Exception:
             return gpd.read_parquet(
-                "s3://spatial-ucr/census/administrative/counties.parquet"
+                "s3://spatial-ucr/census/administrative/counties.parquet",storage_options={"anon": True}
             )
 
     def msa_definitions(self):
